/************************************************************************/
/*                                                                      */
/*                        Copyright (C)                                 */
/*                         Loquendo SpA                                 */
/*                      All Rights Reserved                             */
/*                                                                      */
/************************************************************************/

/*! \file loqtts.h
\brief Loquendo TTS API declarations
*/

/************************************************************************/
/*									*/
/*			    LOQUENDO TTS API				*/
/*									*/
/************************************************************************/

#if !defined tts_H_INCLUDED
#define tts_H_INCLUDED

#include "loqtypes.h"

#if defined __cplusplus
extern "C" {
#endif /* __cplusplus */

/* BEGIN: C API DECLARATIONS */

ttsResultType tts_API_DEFINITION ttsRead
(
    ttsHandleType hReader,
    const void *Input,
    ttsBoolType bAsync,
    ttsBoolType bFromFile,
    size_t *phPromptId
);

ttsResultType tts_API_DEFINITION ttsReadSlice
(
    ttsHandleType hReader,
    const void *Input,
    ttsBoolType bFromFile,
    size_t *phPromptId
);

ttsResultType tts_API_DEFINITION ttsReadNextSlice
(
    ttsHandleType hReader,
    ttsBoolType *pbEnd
);

ttsResultType tts_API_DEFINITION ttsPause(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsResume(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsSkip(
    ttsHandleType hReader,
    ttsSkipType Type,
    signed int nUtterances
);

ttsResultType tts_API_DEFINITION ttsWaitForEndOfSpeech(
    ttsHandleType hReader,
    unsigned long TimeOutMsec,
    ttsBoolType *bSignaled
);

ttsResultType tts_API_DEFINITION ttsStop(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsReset(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsAudioFreeSpace(
    ttsHandleType hReader,
    ttsBoolType *bFreeSpace
);

ttsResultType tts_API_DEFINITION ttsNewLanguage(
    ttsHandleType *phLanguage,
    ttsHandleType hSession,
    const char* Language
);

ttsResultType tts_API_DEFINITION ttsSetLanguage(
    ttsHandleType hReader,
    ttsHandleType hLanguage
);

ttsResultType tts_API_DEFINITION ttsDeleteLanguage(
    ttsHandleType hLanguage
);

ttsResultType tts_API_DEFINITION ttsNewStyle(
    ttsHandleType *phStyle,
    ttsHandleType hSession,
    const char* StyleName
);

ttsResultType tts_API_DEFINITION ttsDeleteStyle(
    ttsHandleType hStyle
);

ttsResultType tts_API_DEFINITION ttsSetStyle(
    ttsHandleType hReader,
    ttsHandleType hStyle
);

ttsResultType tts_API_DEFINITION ttsOpenLexicon(
    ttsHandleType *hLexicon,
    ttsHandleType hReader,
    unsigned int nLex,
    ttsBoolType bReadOnly,
    const char *FileName,
    ttsBoolType bActivate
);

ttsResultType tts_API_DEFINITION ttsActivateLexicon(
    ttsHandleType hLexicon, 
    ttsBoolType bActive
);

ttsResultType tts_API_DEFINITION ttsCloseLexicon(
    ttsHandleType hLexicon
);

ttsResultType tts_API_DEFINITION ttsFindLexiconEntry(
    ttsHandleType hLexicon,
    const char *FindExpression,
    ttsInfoStringType ReplaceExpression,
    const char *LanguageID
);

ttsResultType tts_API_DEFINITION ttsAddLexiconEntry(
    ttsHandleType hLexicon,
    const char * FindExpression,
    const char * ReplaceExpression,
    const char *LanguageID
);

ttsResultType tts_API_DEFINITION ttsRemoveLexiconEntry(
    ttsHandleType hLexicon,
    const char *FindExpression,
    const char *LanguageID
);

ttsResultType tts_API_DEFINITION ttsImportLexicon(
    ttsHandleType hLexicon,
    const char *filename
);

ttsResultType tts_API_DEFINITION ttsExportLexicon(
    ttsHandleType hLexicon,
    const char *filename,
    const char *reserved
);

ttsResultType tts_API_DEFINITION ttsEnumLexiconEntryFirst(
    ttsHandleType *phEnum,
    ttsHandleType hLexicon,
    const char **pFindExpression,
    const char *LanguageID
);

ttsResultType tts_API_DEFINITION ttsEnumLexiconEntryNext(
    ttsHandleType hEnum,
    const char **pFindExpression
);

ttsResultType tts_API_DEFINITION ttsSetPitch(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetPitch(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetSpeed(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetSpeed(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetVolume(
    ttsHandleType hReader,
    int volume
);

ttsResultType tts_API_DEFINITION ttsGetVolume(
    ttsHandleType hReader,
    int *volume
);

ttsResultType tts_API_DEFINITION ttsSetTimbre(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetTimbre(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetAbsolutePitch(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetAbsolutePitch(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetAbsoluteSpeed(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetAbsoluteSpeed(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetAbsoluteVolume(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetAbsoluteVolume(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsSetReverb(
    ttsHandleType hReader,
    int gain,
    int delay
);

ttsResultType tts_API_DEFINITION ttsGetReverb(
    ttsHandleType hReader,
    int *gain,
    int *delay
);

ttsResultType tts_API_DEFINITION ttsSetBalance(
    ttsHandleType hReader,
    int value
);

ttsResultType tts_API_DEFINITION ttsGetBalance(
    ttsHandleType hReader,
    int *value
);

ttsResultType tts_API_DEFINITION ttsAddParametricEQ(
    ttsHandleType hReader,
    float freq,
    float gain,
    float Q
);

ttsResultType tts_API_DEFINITION ttsResetParametricEQ(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsSetGraphicEQPreset(
    ttsHandleType hReader,
    ttsGraphicEQPresetType Preset
);

ttsResultType tts_API_DEFINITION ttsSetGraphicEQBand(
    ttsHandleType hReader,
    ttsGraphicEQBandType Band,
    float Gain
);

ttsResultType tts_API_DEFINITION ttsGetGraphicEQBand(
    ttsHandleType hReader,
    ttsGraphicEQBandType Band,
    float* Gain
);

ttsResultType tts_API_DEFINITION ttsResetGraphicEQ(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsNewVoice(
    ttsHandleType *phVoice,
    ttsHandleType hSession,
    const char *Speaker
);

ttsResultType tts_API_DEFINITION ttsDeleteVoice(
    ttsHandleType hVoice
);

ttsResultType tts_API_DEFINITION ttsSetVoice(
    ttsHandleType hReader,
    ttsHandleType hVoice
);

ttsResultType tts_API_DEFINITION ttsNewLexicon(
    ttsHandleType *phLexicon,
    ttsHandleType hSession,
    const char *LexiconName
);

ttsResultType tts_API_DEFINITION ttsDeleteLexicon(
    ttsHandleType hLexicon
);

ttsResultType tts_API_DEFINITION ttsSetLexicon(
    ttsHandleType hReader,
    ttsHandleType hLexicon,
    size_t LexiconIndex
);

ttsResultType tts_API_DEFINITION ttsLoadPersona(
    ttsHandleType hReader,
    const char *szVoice,
    const char *szLanguage,
    const char *szStyle
);

ttsResultType tts_API_DEFINITION ttsLoadPersonaFromFile(
    ttsHandleType hReader,
    const char *szReader
);

ttsResultType tts_API_DEFINITION ttsSetCallback(
    ttsHandleType hReader,
    void *pCallback,
    void *pUser,
    ttsCallbackType Type
);

ttsResultType tts_API_DEFINITION ttsGetVersionInfo(
    ttsInfoStringType StrVer
);

const char tts_API_DEFINITION_P ttsGetErrorMessage(
    ttsResultType ErrNo
);

ttsBoolType tts_API_DEFINITION ttsTestPersona(
    ttsHandleType hSession,
    const char * Speaker,
    const char * Language,
    const char * Style
);

ttsResultType tts_API_DEFINITION ttsInject(
    ttsHandleType hReader,
    const char * command
);

ttsResultType tts_API_DEFINITION ttsPhoneticTranscription(
    ttsHandleType hReader,
    const void * text, 
    void * TranscriptionBuffer, 
    const size_t BufferLen, 
    size_t * TranscriptionLen
);

ttsResultType tts_API_DEFINITION ttsSetAudio(
    ttsHandleType hReader,
    const char *AudioDestName, 
    const char *AudioDeviceName, 
    unsigned int SampleRate,
    ttsAudioEncodingType coding,
    ttsAudioSampleType nChannels,
    const void *pUser
);

ttsResultType tts_API_DEFINITION ttsGetRobotsList(ttsInfoStringType list);

ttsResultType tts_API_DEFINITION ttsQuery(
    ttsHandleType hSession,
    ttsObjectType uObject,
    const char *sDataToRetrieve,
    const char *sFilter,
    char *sResultBuffer,
    size_t uResultBufferSize,
    ttsBoolType bLoadedOnly,
    ttsBoolType bRescanFileSystem
);

ttsResultType tts_API_DEFINITION ttsQueryAttribute(
    ttsHandleType hSession,
    ttsObjectType uObject,
    const char *sAttribute,
    const char *sObjectId,
    char *sResultBuffer,
    size_t uResultBufferSize
);

ttsResultType tts_API_DEFINITION ttsEnumFirst(
    ttsHandleType *phEnum,
    ttsHandleType hSession,
    ttsObjectType uObject,
    const char *sFilter,
    char **pResult
);

ttsResultType tts_API_DEFINITION ttsEnumNext(
    ttsHandleType hEnum,
    char **pResult
);

ttsResultType tts_API_DEFINITION ttsEnumClose(
    ttsHandleType hEnum
);

ttsResultType tts_API_DEFINITION ttsLocateSpeechAtomInventory(
    ttsHandleType hVoice,
    ttsHandleType *hInventory,
    const char *path
);

ttsResultType tts_API_DEFINITION ttsGetSpeechAtom(
    ttsHandleType *hNode,
    ttsHandleType hParent,
    const char **name,
    const void **info
);

ttsResultType tts_API_DEFINITION ttsValidateXML(
    ttsHandleType hReader,
    const void *Input,
    ttsBoolType bFromFile
);

ttsResultType tts_API_DEFINITION ttsSSMLConvert(
    ttsHandleType hReader,
    const void *Input,
    char **Output, 
    ttsBoolType bFromFile
);

ttsResultType tts_API_DEFINITION ttsNewSession(
    ttsHandleType *phSession,
    const char *SessionName
);

ttsResultType tts_API_DEFINITION ttsDeleteSession(
    ttsHandleType hSession
);

ttsResultType tts_API_DEFINITION ttsNewReader(
    ttsHandleType *phReader,
    ttsHandleType hSession
);

ttsResultType tts_API_DEFINITION ttsDeleteReader(
    ttsHandleType hReader
);

ttsResultType tts_API_DEFINITION ttsLanguageGuess(
    ttsHandleType hReader,
    const void *Input,
    ttsInfoStringType GuessedLanguage,
    ttsBoolType bFromFile
);

ttsResultType tts_API_DEFINITION ttsSetParam(
    ttsHandleType hObject,
    const char * sName,
    const char * sValue
);

ttsResultType tts_API_DEFINITION ttsGetParam(
    ttsHandleType hObject,
    const char * sName,
    ttsInfoStringType sValue
);

ttsResultType tts_API_DEFINITION ttsSetTextEncoding(
    ttsHandleType hReader,
    ttsTextEncodingType encoding
);

ttsResultType tts_API_DEFINITION ttsGetTextEncoding(
    ttsHandleType hReader,
    ttsTextEncodingType *encoding
);

ttsResultType tts_API_DEFINITION ttsSetTextFormat(
    ttsHandleType hReader,
    ttsTextFormatType format
);

ttsResultType tts_API_DEFINITION ttsGetTextFormat(
    ttsHandleType hReader,
    ttsTextFormatType *format
);

ttsResultType tts_API_DEFINITION ttsSaveCF(
    ttsHandleType hObject,
    const char *sFileName
);

ttsResultType tts_API_DEFINITION ttsDeleteCF(
    ttsHandleType hSession,
    ttsObjectType uObject,
    const char *sId
);

ttsResultType tts_API_DEFINITION ttsClone(
    ttsHandleType *hNewObject,
    ttsHandleType hObject,
    const char *sNewId
);

ttsResultType tts_API_DEFINITION ttsSaveConfigurationParam(
    const char * area,
    const char * key,
    const char * value
);

ttsResultType tts_API_DEFINITION ttsLoadConfigurationParam(
    const char * area,
    const char * key,
    ttsInfoStringType value
);

ttsResultType tts_API_DEFINITION ttsDeleteConfiguration(
    const char * area
);

ttsResultType tts_API_DEFINITION ttsGetPhonemeInfo(
    ttsHandleType hObject,
    const char **pLabel,
    unsigned int *pDuration
);

ttsResultType tts_API_DEFINITION ttsGetPCM(
    ttsHandleType hObject,
    const void **pBuffer,
    size_t *pnSamples,
    ttsBoolType *bComplete
);

ttsResultType tts_API_DEFINITION ttsGetTag(
    ttsHandleType hObject,
    const char **tag
);

ttsResultType tts_API_DEFINITION ttsCheckPhoneticTranscription(
    ttsHandleType hReader,
    const char *PhoneticString
);

ttsResultType tts_API_DEFINITION ttsClaimLicense(
    ttsHandleType hReader,
    unsigned int *time2wait
);

ttsResultType tts_API_DEFINITION ttsUnclaimLicense(
    ttsHandleType hReader,
    unsigned int *time2wait
);

ttsResultType tts_API_DEFINITION ttsEnableEvent(
    ttsHandleType hReader,
    ttsEventType evt,
    ttsBoolType bEnabled
);

ttsResultType tts_API_DEFINITION ttsSetURLCallback(
    ttsHandleType hReader,
    ttsURLCallbackType pfnCallback,
    void *pUser
);

ttsResultType tts_API_DEFINITION ttsEnumConfigurationParameterFirst(
    ttsHandleType *phEnum,
    ttsBoolType bReadOnly,
    const char **pKey,
    const char **pDesc
);

ttsResultType tts_API_DEFINITION ttsEnumConfigurationParameterNext(
    ttsHandleType hEnum,
    const char **pKey,
    const char **pDesc
);

ttsBoolType tts_API_DEFINITION ttsIsMp3SupportInstalled(ttsInfoStringType libName);

ttsResultType tts_API_DEFINITION ttsEnumModulesInit(
    ttsHandleType *hEnumModule
);
ttsResultType tts_API_DEFINITION ttsEnumModulesClose(
    ttsHandleType hEnumModule
);

ttsBoolType tts_API_DEFINITION ttsEnumModulesNext(
    ttsHandleType hEnumModule,
    ttsInfoStringType name,
    ttsInfoStringType version
);


void tts_API_DEFINITION ttsSetUserConfigPath(const char *userConfigPath, ttsBoolType bAllUser);

ttsResultType tts_API_DEFINITION ttsSetMode(
    ttsHandleType hReader,
    const char * mode
);

/* END: C API DECLARATIONS */

#if defined __cplusplus
} // extern "C"
#endif

#endif	/* tts_H_INCLUDED */
