/************************************************************************/
/*                                                                      */
/*                        Copyright (C)                                 */
/*                         Loquendo SpA                                 */
/*                      All Rights Reserved                             */
/*                                                                      */
/************************************************************************/

/*! \file loqtypes.h
\brief Loquendo TTS costants and types
*/

/************************************************************************/
/*									*/
/*			    LOQUENDO TTS TYPES				*/
/*									*/
/************************************************************************/

#if !defined tts_H_TYPES_INCLUDED
#define tts_H_TYPES_INCLUDED
#include <stdlib.h>

//#define OLD_QUERY

/****************************************************************************/
/*                            GENERIC					    */
/****************************************************************************/

typedef unsigned char ttsBoolType;
typedef int (*ttsMagicNumberType)(void);

typedef int ttsInt32Type;		/* signed 32 bit */
typedef unsigned int ttsUint32Type;	/* unsigned 32 bit */
#define TTS_INT32_MAX	2147483647
#define TTS_UINT32_MAX	4294967295U

#define ttsTRUE	    1u
#define ttsFALSE    0u

#define ttsSTRINGMAXLEN 512
#define ttsIDMAXLEN 80
#define ttsINFINITE ((size_t)-1) /* max size_t number			    */

typedef char ttsInfoStringType[ttsSTRINGMAXLEN];

#define tts_GET_VERSION		"GetVersion"
#define tts_LOAD_UTIL_SYMBOLS	"LoadUtilSymbols"

#define TTSCOMPILERCHECK(type,name) { type Compiler_Error_Check; Compiler_Error_Check = name; }

/****************************************************************************/
/*                            ERROR HANDLING		                    */
/****************************************************************************/

typedef int ttsResultType;
#define tts_OK                  0L
#define ttsERROR_FILEWRITE      1
#define ttsERROR_FILEREAD       2
#define ttsERROR_NOTINIT        3
#define ttsERROR_INTERNAL       4
#define ttsERROR_OUTOFMEMORY    5
#define ttsERROR_CONFIGURATION  6
#define ttsERROR_ACCESSDENIED   7
#define ttsERROR_SYNTAX         8
#define ttsERROR_DEVICEBUSY     9
#define ttsERROR_LICENSING      10
#define ttsERROR_OBSOLETE       11
#define ttsERROR_INVALIDPARAM   12
#define ttsERROR_DATAOVERFLOW   13
#define ttsERROR_EXTERNALPLUGIN 14
#define ttsERROR_INCOMPATIBLE   15
#define ttsERROR_TOOMANYITEMS   16
#define ttsERROR_DUPLICATEITEM  17
#define ttsERROR_UNSUPPORTED    18
#define ttsERROR_PISNOTFOUND    19

/****************************************************************************/
/*                            NOTIFICATIONS AND EVENTS	                    */
/****************************************************************************/

typedef enum {
    TTSCALLBACKFUNCTION = 0,
    TTSCALLBACKWINDOW = 1,
    TTSCALLBACKEVENT = 2,
    TTSCALLBACKPASCALFUNCTION = 3
} ttsCallbackType;

typedef enum {
    TTSEVT_AUDIOSTART = 0,
    TTSEVT_ENDOFSPEECH,	
    TTSEVT_LANGUAGEPHONEME,
    TTSEVT_VOICEPHONEME,
    TTSEVT_DATA,
    TTSEVT_TEXT,
    TTSEVT_SENTENCE,
    TTSEVT_BOOKMARK,
    TTSEVT_TAG,
    TTSEVT_PAUSE,
    TTSEVT_RESUME,
    TTSEVT_FREESPACE,
    TTSEVT_NOTSENT,
    TTSEVT_AUDIO,
    TTSEVT_VOICECHANGE,
    TTSEVT_LANGUAGECHANGE,
    TTSEVT_ERROR,
    TTSEVT_JUMP,
    TTSEVT_PARAGRAPH,
    TTSEVT_TEXTENCODING,
    TTSEVT_STYLECHANGE,
    TTSEVT_PERSONACHANGE,
    TTSEVT_SAYASCHANGE,
    TTSEVT_MODECHANGE
} ttsEventType;

#define TTSEVT_WINUSER	1024
#define TTSEVT_WINMESSAGE(x) ((x) - TTSEVT_WINUSER - WM_USER)
typedef void (* ttsCallbackFunctionType)(size_t PromptID, ttsEventType nReason, void *lData, void *pUser);
#if defined _WIN32
typedef void (__stdcall *ttsCallbackPascalFunctionType)(size_t PromptID, ttsEventType nReason, void *lData, void *pUser);
#endif

typedef ttsBoolType (*ttsURLCallbackType)(const char *url, char *info, char *outfile, void *pUser);

/* session or instance handle */
typedef void *ttsHandleType;

/* reserved */
typedef void * (*ttsOutputFunctionType) (void *data, void *destination);

/* pointer functions stuff for dynamic loading */
typedef void * (*ttspFuncType) (void);
typedef const char * ttsProcIdType;

/* skip API */
typedef enum ttsSkipType {
    TTSSKIP_SENTENCE,
    TTSSKIP_PROMPT,
    TTSSKIP_GOTOSENTENCE
} ttsSkipType;

/* querable objects */
typedef enum {
    TTSOBJECTREADER = 0,
    TTSOBJECTVOICE = 1,
    TTSOBJECTLANGUAGE = 2,
    TTSOBJECTSTYLE = 3,
    TTSOBJECTPERSONA = 4,
    TTSOBJECTSESSION = 5
} ttsQueryType, ttsObjectType;

/* three-state variable */
typedef enum {
    TTS3STATE_YES,
    TTS3STATE_NO,
    TTS3STATE_MAYBE
} tts3StateType;

/****************************************************************************/
/*                            AUDIO HANDLING	                            */
/****************************************************************************/
#define TTSAUDIO_OPEN		    "AudioOpen"
#define TTSAUDIO_CLOSE		    "AudioClose"
#define TTSAUDIO_PUTDATA	    "AudioPutData"	
#define TTSAUDIO_STOP		    "AudioStop"
#define TTSAUDIO_PAUSE		    "AudioPause"
#define TTSAUDIO_RESUME		    "AudioResume"
#define TTSAUDIO_GETERRORMESSAGE    "AudioGetError"

/* audio destination */
typedef enum {
    tts_MONO = 1,
    tts_STEREO = 2
} ttsAudioSampleType;

typedef enum {
    tts_LINEAR,
    tts_ALAW,
    tts_ULAW
} ttsAudioEncodingType, ttsAudioCodingType;

/* Graphic Equalizer */
typedef enum {
    tts_30Hz,
    tts_40Hz,
    tts_50Hz,
    tts_63Hz,
    tts_80Hz,
    tts_100Hz,
    tts_125Hz,
    tts_160Hz,
    tts_200Hz,
    tts_250Hz,
    tts_315Hz,
    tts_400Hz,
    tts_500Hz,
    tts_630Hz,
    tts_800Hz,
    tts_1000Hz,
    tts_1250Hz,
    tts_1600Hz,
    tts_2000Hz,
    tts_2500Hz,
    tts_3150Hz,
    tts_4000Hz,
    tts_5000Hz,
    tts_6300Hz,
    tts_8000Hz,
    tts_10000Hz,
    tts_12500Hz,
    tts_16000Hz,
    tts_20000Hz,
    tts_25000Hz
} ttsGraphicEQBandType;

typedef enum {
    tts_GraphicEQPreset_BassBoost,
    tts_GraphicEQPreset_LowFidelity,
    tts_GraphicEQPreset_NotchTwoOfThree,
    tts_GraphicEQPreset_ForbiddenPlanet,
    tts_GraphicEQPreset_HighPass,
    tts_GraphicEQPreset_LowPass,
    tts_GraphicEQPreset_VoicePresence
} ttsGraphicEQPresetType;

#define TTS_AUDIOFULL -1

typedef ttsResultType (*ttsAudioOpenType)(void **channel, const char *specification, size_t SampleRate, ttsAudioEncodingType coding, ttsAudioSampleType nChannels, ttsBoolType *bRealTime, const void *pUser);
typedef ttsResultType (*ttsAudioCloseType)(void *channel);
typedef ttsResultType (*ttsAudioPutDataType)(void *channel,void *pData,size_t nBytes,size_t *nSent);
typedef ttsResultType (*ttsAudioStopType)(void *channel);
typedef ttsResultType (*ttsAudioPauseType)(void *channel);
typedef ttsResultType (*ttsAudioResumeType)(void *channel);
typedef ttsResultType (*ttsAudioGetErrorMessageType)(ttsResultType ErrorCode,char *message,size_t size);
typedef ttsResultType (*ttsGetVersionType) (char * Version);
typedef ttsBoolType (*ttsLoadUtilSymbolsType) (ttsHandleType hLibrary);

/****************************************************************************/
/*                           TEXT ENCODING AND FORMAT                       */
/****************************************************************************/
typedef enum {
    TTSDEFAULTENCODING=0,
    TTSAUTODETECTENCODING=1,
    TTSISO=2,
    TTSANSI=3,
    TTSOEM=4,
    TTSUTF8 = 65001,
    TTSUTF16 = 1200,
    TTSUTF16BIGENDIAN = 1201,
    TTSCP_437 = 437,	    /* msdos-united-states */
    TTSCP_858 = 858,	    /* oem-western-european (including euro sign) */
    TTSCP_737 = 737,	    /* msdos-greek */
    TTSCP_852 = 852,	    /* msdos-central-european */
    TTSCP_855 = 855,	    /* msdos-cyrillic (old) */
    TTSCP_857 = 857,	    /* msdos-turkish */
    TTSCP_866 = 866,	    /* msdos-cyrillic */
    TTSISO_8859_1 = 28591,  /* iso-western */
    TTSISO_8859_2 = 28592,  /* iso-central-european */
    TTSISO_8859_3 = 28593,  /* not yet implemented */
    TTSISO_8859_4 = 28594,  /* not yet implemented */
    TTSISO_8859_5 = 28595,  /* iso-cyrillic */
    TTSISO_8859_6 = 28596,  /* iso-arabic */
    TTSISO_8859_7 = 28597,  /* iso-greek */
    TTSISO_8859_8 = 28598,  /* not yet implemented */
    TTSISO_8859_9 = 28599,  /* iso-turkish */
    TTSISO_8859_15 = 28605, /* iso-latin-15 (including euro sign) */
    TTSWINDOWS_1250 = 1250, /* windows-central-european */
    TTSWINDOWS_1251 = 1251, /* windows-cyrillic */
    TTSWINDOWS_1252 = 1252, /* windows-ansi-western */
    TTSWINDOWS_1253 = 1253, /* windows-greek */
    TTSWINDOWS_1254 = 1254, /* windows-turkish */
    TTSWINDOWS_1255 = 1255, /* not yet implemented */
    TTSWINDOWS_1256 = 1256, /* windows-arabic */
    TTSWINDOWS_1257 = 1257, /* not yet implemented */
    TTSWINDOWS_1258 = 1258,  /* not yet implemented */
    TTSBUCKWALTER = 9000    /* arabic transliteration */
} ttsTextEncodingType;

typedef enum {
    TTSAUTODETECTFORMAT,
    TTSPLAINTEXT,
    TTSSSML
} ttsTextFormatType;

#if !defined __SYMBIAN32__
#define EXPORT_C
#define IMPORT_C
#endif
#define TTSCALLBACK 

#if defined __cplusplus
#define ttsNEED_C_LINKING "C"
#else
#define ttsNEED_C_LINKING
#endif

#if defined _WIN32
#define ttsCALLINGCONVENTION _stdcall
#else
#define ttsCALLINGCONVENTION
#endif

#if defined _WIN32 && !defined ttsAPI_EXPLICITLOADING && !defined _WIN64
#if defined tts_COMPILING_API_LIBRARY || defined STATIC_LIB || defined INCLUDE_STATIC_LIB
#define tts_API_DEFINITION __declspec(dllexport) ttsCALLINGCONVENTION
#define tts_API_DEFINITION_P __declspec(dllexport) * ttsCALLINGCONVENTION
#define tts_CLASS_DEFINITION __declspec(dllexport)
#else
#define tts_API_DEFINITION __declspec(dllimport) ttsCALLINGCONVENTION
#define tts_API_DEFINITION_P __declspec(dllimport) * ttsCALLINGCONVENTION
#define tts_CLASS_DEFINITION __declspec(dllimport)
#endif /* INCLUDEDBYTHEDLL || STATIC_LIB */

#else  /* !_WIN32 */
#define tts_API_DEFINITION
#define tts_API_DEFINITION_P *
#define tts_CLASS_DEFINITION
#endif /* _WIN32 */

#if !defined ttsAPI_EXPLICITLOADING
#define ttsAPI_IMPLICITLOADING
#endif

#endif /* defined tts_H_TYPES_INCLUDED */
